import setuptools
from pathlib import Path
setuptools.setup(
    name="KonbiLockerLite",
    version="0.1.4",
    long_description=Path("README.md").read_text(),
    packages=setuptools.find_packages()
)
